@@ -112,4 +112,5 @@ class Repository(metaclass=abc.ABCMeta):
         return self
 
     async def __aexit__(self, cls, exc, tb):
-        self.async_teardown_context(cls, exc, tb)
+        if hasattr(self, 'async_teardown_context'):
+            return await self.async_teardown_context(cls, exc, tb)
